'\"
'\" The definitions below are for supplemental macros used in Tcl/Tk
'\" manual entries.
'\"
'\" .AP type name in/out ?indent?
'\"	Start paragraph describing an argument to a library procedure.
'\"	type is type of argument (int, etc.), in/out is either "in", "out",
'\"	or "in/out" to describe whether procedure reads or modifies arg,
'\"	and indent is equivalent to second arg of .IP (shouldn't ever be
'\"	needed;  use .AS below instead)
'\"
'\" .AS ?type? ?name?
'\"	Give maximum sizes of arguments for setting tab stops.  Type and
'\"	name are examples of largest possible arguments that will be passed
'\"	to .AP later.  If args are omitted, default tab stops are used.
'\"
'\" .BS
'\"	Start box enclosure.  From here until next .BE, everything will be
'\"	enclosed in one large box.
'\"
'\" .BE
'\"	End of box enclosure.
'\"
'\" .CS
'\"	Begin code excerpt.
'\"
'\" .CE
'\"	End code excerpt.
'\"
'\" .VS ?br?
'\"	Begin vertical sidebar, for use in marking newly-changed parts
'\"	of man pages.  If an argument is present, then a line break is
'\"	forced before starting the sidebar.
'\"
'\" .VE
'\"	End of vertical sidebar.
'\"
'\" .DS
'\"	Begin an indented unfilled display.
'\"
'\" .DE
'\"	End of indented unfilled display.
'\"
'\" .SO
'\"	Start of list of standard options for a Tk widget.  The
'\"	options follow on successive lines, in four columns separated
'\"	by tabs.
'\"
'\" .SE
'\"	End of list of standard options for a Tk widget.
'\"
'\" .OP cmdName dbName dbClass
'\"	Start of description of a specific option.  cmdName gives the
'\"	option's name as specified in the class command, dbName gives
'\"	the option's name in the option database, and dbClass gives
'\"	the option's class in the option database.
'\"
'\" .UL arg1 arg2
'\"	Print arg1 underlined, then print arg2 normally.
'\"
'\"	# Set up traps and other miscellaneous stuff for Tcl/Tk man pages.
.if t .wh -1.3i ^B
.nr ^l \n(.l
.ad b
'\"	# Start an argument description
.de AP
.ie !'\\$4'' .TP \\$4
.el \{\
.   ie !'\\$2'' .TP \\n()Cu
.   el          .TP 15
.\}
.ie !'\\$3'' \{\
.ta \\n()Au \\n()Bu
\&\\$1	\\fI\\$2\\fP	(\\$3)
.\".b
.\}
.el \{\
.br
.ie !'\\$2'' \{\
\&\\$1	\\fI\\$2\\fP
.\}
.el \{\
\&\\fI\\$1\\fP
.\}
.\}
..
'\"	# define tabbing values for .AP
.de AS
.nr )A 10n
.if !'\\$1'' .nr )A \\w'\\$1'u+3n
.nr )B \\n()Au+15n
.\"
.if !'\\$2'' .nr )B \\w'\\$2'u+\\n()Au+3n
.nr )C \\n()Bu+\\w'(in/out)'u+2n
..
.AS Tcl_Interp Tcl_CreateInterp in/out
'\"	# BS - start boxed text
'\"	# ^y = starting y location
'\"	# ^b = 1
.de BS
.br
.mk ^y
.nr ^b 1u
.if n .nf
.if n .ti 0
.if n \l'\\n(.lu\(ul'
.if n .fi
..
'\"	# BE - end boxed text (draw box now)
.de BE
.nf
.ti 0
.mk ^t
.ie n \l'\\n(^lu\(ul'
.el \{\
.\"	Draw four-sided box normally, but don't draw top of
.\"	box if the box started on an earlier page.
.ie !\\n(^b-1 \{\
\h'-1.5n'\L'|\\n(^yu-1v'\l'\\n(^lu+3n\(ul'\L'\\n(^tu+1v-\\n(^yu'\l'|0u-1.5n\(ul'
.\}
.el \}\
\h'-1.5n'\L'|\\n(^yu-1v'\h'\\n(^lu+3n'\L'\\n(^tu+1v-\\n(^yu'\l'|0u-1.5n\(ul'
.\}
.\}
.fi
.br
.nr ^b 0
..
'\"	# VS - start vertical sidebar
'\"	# ^Y = starting y location
'\"	# ^v = 1 (for troff;  for nroff this doesn't matter)
.de VS
.if !'\\$1'' .br
.mk ^Y
.ie n 'mc \s12\(br\s0
.el .nr ^v 1u
..
'\"	# VE - end of vertical sidebar
.de VE
.ie n 'mc
.el \{\
.ev 2
.nf
.ti 0
.mk ^t
\h'|\\n(^lu+3n'\L'|\\n(^Yu-1v\(bv'\v'\\n(^tu+1v-\\n(^Yu'\h'-|\\n(^lu+3n'
.sp -1
.fi
.ev
.\}
.nr ^v 0
..
'\"	# Special macro to handle page bottom:  finish off current
'\"	# box/sidebar if in box/sidebar mode, then invoked standard
'\"	# page bottom macro.
.de ^B
.ev 2
'ti 0
'nf
.mk ^t
.if \\n(^b \{\
.\"	Draw three-sided box if this is the box's first page,
.\"	draw two sides but no top otherwise.
.ie !\\n(^b-1 \h'-1.5n'\L'|\\n(^yu-1v'\l'\\n(^lu+3n\(ul'\L'\\n(^tu+1v-\\n(^yu'\h'|0u'\c
.el \h'-1.5n'\L'|\\n(^yu-1v'\h'\\n(^lu+3n'\L'\\n(^tu+1v-\\n(^yu'\h'|0u'\c
.\}
.if \\n(^v \{\
.nr ^x \\n(^tu+1v-\\n(^Yu
\kx\h'-\\nxu'\h'|\\n(^lu+3n'\ky\L'-\\n(^xu'\v'\\n(^xu'\h'|0u'\c
.\}
.bp
'fi
.ev
.if \\n(^b \{\
.mk ^y
.nr ^b 2
.\}
.if \\n(^v \{\
.mk ^Y
.\}
..
'\"	# DS - begin display
.de DS
.RS
.nf
.sp
..
'\"	# DE - end display
.de DE
.fi
.RE
.sp
..
'\"	# SO - start of list of standard options
.de SO
.SH "STANDARD OPTIONS"
.LP
.nf
.ta 4c 8c 12c
.ft B
..
'\"	# SE - end of list of standard options
.de SE
.fi
.ft R
.LP
See the \\fBoptions\\fR manual entry for details on the standard options.
..
'\"	# OP - start of full description for a single option
.de OP
.LP
.nf
.ta 4c
Command-Line Name:	\\fB\\$1\\fR
Database Name:	\\fB\\$2\\fR
Database Class:	\\fB\\$3\\fR
.fi
.IP
..
'\"	# CS - begin code excerpt
.de CS
.RS
.nf
.ta .25i .5i .75i 1i
..
'\"	# CE - end code excerpt
.de CE
.fi
.RE
..
.de UL
\\$1\l'|0\(ul'\\$2
..
.TH "Owtcl" TCL "20/January/2005" "Tcl"
.HS table tk
.BS
.SH NAME
Owtcl \- OWFS library access commands for Tcl
.SH SYNOPSIS
\fBpackage \fBrequire \fBow
.sp
\fBow\fI \fIoption \fR?\fIarg ...\fR?
.sp
\fB::OW::init\fI \fIinterface \fR?\fIinterface ...\fR? \fR?\fIarg ...\fR?
.br
\fB::OW::finish
.br
\fB::OW::isconnect
.br
\fB::OW::get\fI \fR?\fIpath\fR? \fR?\fIarg ...\fR?
.br
\fB::OW::put\fI \fIpath \fR?\fIvalue\fR?
.br
\fB::OW::isdirectory\fI \fIpath
.br
\fB::OW::isdir\fI \fIpath
.br
\fB::OW::exists\fI \fIpath
\fR
.SH DESCRIPTION
'\"
'\" Copyright (c) 2003-2004 Paul H Alfille, MD
'\" (paul.alfille@gmail.com)
'\"
'\" Program manual page for the OWFS -- 1-wire filesystem package
'\" Based on Dallas Semiconductor, Inc's datasheets, and trial and error.
'\"
'\" Free for all use. No warranty. None. Use at your own risk.
'\"
.SS 1-Wire
.I 1-wire 
is a wiring protocol and series of devices designed and manufactured
by Dallas Semiconductor, Inc. The bus is a low-power low-speed low-connector
scheme where the data line can also provide power.
.PP
Each device is uniquely and unalterably numbered during manufacture. There are a wide variety
of devices, including memory, sensors (humidity, temperature, voltage,
contact, current), switches, timers and data loggers. More complex devices (like
thermocouple sensors) can be built with these basic devices. There are also
1-wire devices that have encryption included.
.PP
The 1-wire scheme uses a single 
.I bus master
and multiple
.I slaves
on the same wire. The bus master initiates all communication. The slaves can be 
individually discovered and addressed using their unique ID.
.PP
Bus masters come in a variety of configurations including serial, parallel, i2c, network or USB
adapters.
.SS OWFS design
.I OWFS
is a suite of programs that designed to make the 1-wire bus and its
devices easily accessible. The underlying principle is to create a virtual
filesystem, with the unique ID being the directory, and the individual
properties of the device are represented as simple files that can be read and written.
.PP 
Details of the individual slave or master design are hidden behind a consistent interface. The goal is to 
provide an easy set of tools for a software designer to create monitoring or control applications. There 
are some performance enhancements in the implementation, including data caching, parallel access to bus 
masters, and aggregation of device communication. Still the fundamental goal has been ease of use, flexibility
and correctness rather than speed.
.SS owtcl
.B owtcl (3)
is a Tcl extension that provides an interface to OWFS. The underlying interface to the 1-wire bus is identical to 
.B owfs (1)
(filesystem view) and 
.B owhttpd (1) 
web server interface. Only the top
layer has been modified to return native Tcl data.
.SH COMMANDS
Performs one of several operations, depending on \fIoption\fR.
The legal \fIoption\fRs (which may be abbreviated) are:
.TP
\fBow open \fIarg ...\fR
Connect to 1-wire adapter or \fIowserver\fR. \fIarg ...\fR defines a way of
connection to the 1-wire bus.
.br
The full set of initialization args is extensive. They correspond roughly to the command line args of
.B owfs (1)
.B owhttpd (1)
and
.B owftpd (1)

.TP
\fBow close
Close connection to 1-wire bus or owserver.

.TP
\fBow version\fR ?\fI-list\fR?
Return version of the owtcl and owlib/

.TP
\fBow opened
Return 1 if connected to 1-wire adapter or \fIowserver\fR, otherwise 0.

.TP
\fBow error\fR \fIlevel\fR \fIvalue\fR
Set debug options. See
.B owfs (5)

.TP
\fBow error\fR \fIprint\fR \fIvalue\fR
Set debug options. See
.B owfs (5)

.TP
\fBow get\fR \fIpath\fR \fR?\fI-list\fR?
Returns contents of OWFS directory as the list if path contains name OWFS directory.
If path is name of OWFS file, returns of contents of this file. For files *.ALL
returns a values list.


.TP
\fBow put \fIpath \fR\fIvalue\fR
Puts \fIvalue\fR in OWFS file indicated in \fIpath\fR. For files *.ALL use a value
list.

.TP
\fBow isdirectory \fIpath
If \fIpath\fR is the directory return 1. Otherwise return 0.

.TP
\fBow isdir \fIpath
Synonym of \fBow isdirectory

.TP
\fBow set \fIpath
Creates a new \fBow\fR-like command with root in the \fIpath\fR.
A new command allows options \fIget\fR, \fIput\fR, \fIisdirectory\fR, \fIisdir\fR and \fIset\fR.


.SH LOW-LEVEL COMMANDS
The following low-level commands are possible:
.TP
\fB::OW::init \fIinterface \fR?\fIinterface ...\fR? \fR?\fIarg ...\fR?
Connect to 1-wire adapter or \fIowserver\fR. \fIinterface\fR and \fIarg ...\fR defines a way of
connection to the 1-wire bus.
.br
The full set of initialization options is extensive. They correspond roughly to the command line options of
,B owfs (1)
.B owhttpd (1)
and
.B owftpd (1)

.TP
\fB::OW::finish
Close connection to 1-wire bus or owserver.

.TP
\fB::OW::isconnect
Return 1 if connected to 1-wire adapter or \fIowserver\fR, otherwise 0.

.TP
\fB::OW::get \fR?\fIpath\fR? \fR?\fI-list\fR?
Returns contents of OWFS directory as the list if path contains name OWFS directory.
If path is name of OWFS file, returns of contents of this file. For files *.ALL
returns a values list. If path is not defined, contents of root OWFS directory come
back.

.TP
\fB::OW::put \fIpath \fR?\fIvalue\fR?
Puts \fIvalue\fR in OWFS file indicated in \fIpath\fR. For files *.ALL use a value
list. If /fIvalue\fR is not defined, puts a empty string.

.TP
\fB::OW::isdirectory \fIpath
If \fIpath\fR is the directory - return 1. Otherwise return 0.

.TP
\fB::OW::isdir \fIpath
Synonym of \fB::OW::isdirectory

.TP
\fB::OW::exists \fIpath
If \fIpath\fR is exists - return 1. Otherwise return 0.

.SH EXAMPLE
.CS
package require ow

ow open \-d /dev/ttyS0 \-t 60

set save_templow [ow get /28.86BF80000000/templow]
ow put /28.86BF80000000/templow 10

set room_sensor [ow set /28.86BF80000000]
$room_sensor put temphigh 50

set room_temp [$room_sensor set temperature]
set current_temp [$room_temp get]
.CE

.SH SEE ALSO
.SS Programs
.B owfs (1) owhttpd (1) owftpd (1) owserver (1)
.B owdir (1) owread (1) owwrite (1) owpresent (1)
.B owtap (1)
.SS Configuration and testing
.B owfs (5) owtap (1) owmon (1)
.SS Language bindings
.B owtcl (3) owperl (3) owcapi (3)
.SS Clocks
.B DS1427 (3) DS1904(3) DS1994 (3) DS2404 (3) DS2404S (3) DS2415 (3) DS2417 (3)
.SS ID
.B DS2401 (3) DS2411 (3) DS1990A (3)
.SS Memory
.B DS1982 (3) DS1985 (3) DS1986 (3) DS1991 (3) DS1992 (3) DS1993 (3) DS1995 (3) DS1996 (3) DS2430A (3) DS2431 (3) DS2433 (3) DS2502 (3) DS2506 (3) DS28E04 (3) DS28EC20 (3)
.SS Switches
.B DS2405 (3) DS2406 (3) DS2408 (3) DS2409 (3) DS2413 (3) DS28EA00 (3)
.SS Temperature
.B DS1822 (3) DS1825 (3) DS1820 (3) DS18B20 (3) DS18S20 (3) DS1920 (3) DS1921 (3) DS1821 (3) DS28EA00 (3) DS28E04 (3)
.SS Humidity
.B DS1922 (3)
.SS Voltage
.B DS2450 (3)
.SS Resistance
.B DS2890 (3)
.SS Multifunction (current, voltage, temperature)
.B DS2436 (3) DS2437 (3) DS2438 (3) DS2751 (3) DS2755 (3) DS2756 (3) DS2760 (3) DS2770 (3) DS2780 (3) DS2781 (3) DS2788 (3) DS2784 (3)
.SS Counter
.B DS2423 (3)
.SS LCD Screen
.B LCD (3) DS2408 (3)
.SS Crypto
.B DS1977 (3)
.SS Pressure
.B DS2406 (3) -- TAI8570
.SH AVAILABILITY
http://www.owfs.org
.SH AUTHOR
Serg Oskin (serg@oskin.ru)
.sp

